import React, { useState, useEffect } from 'react'
import ToolUserView from './View'
import {
    getListEmployees,
    deleteEmployee,
    changeStatusEmployee,
} from 'app/apis/Functions/Employee'
import { useHistory } from 'react-router-dom'
import KEY from 'app/assets/Key'
import { connect } from 'react-redux'
import { showLoading, hideLoading } from 'app/redux/actions/loadingAction'
import { toast } from 'react-toastify'
import useDebounce from 'app/hooks/useDebounce'
import { useTranslation } from 'react-i18next'
import {
    dropdownDepartment,
    dropdownUserGroup,
} from 'app/apis/Functions/dropdown'

const ToolNotificate = (props) => {
    const [txtSearch, setTxtSearch] = useState('')
    const [activeSelected, setActiveSeleted] = useState(null)
    const [changeActive, setChangeActive] = useState(1)
    const searchDebount = useDebounce(txtSearch, 1000)
    const [pageIndex, setPageIndex] = useState(0)
    const [pageSize] = useState(10)
    const [totalRecords, setTotalRecord] = useState(0)
    const [status, setStatus] = useState()
    const history = useHistory()
    const { t } = useTranslation()
    const [data, setData] = useState([])
    const [permissions, setPermissions] = useState([])
    const [role, setRole] = useState()
    const [listRole, setListRole] = useState([])

    useEffect(() => {
        getUserGroup()
    }, [])

    const handeChangeActive = async (id, status_id) => {
        props.showLoading()
        const res = await changeStatusEmployee({ id: id, status_id })
        props.hideLoading()
        if (res.data.code == 200) {
            getData()
            toast.success('Thay đổi trạng thái thành công!', {
                theme: 'colored',
            })
        } else {
            toast.error(t(res.data.error), {
                theme: 'colored',
            })
        }
    }

    const getData = async (isInit) => {
        try {
            props.showLoading()
            let res
            if (isInit) {
                setPageIndex(0)
                res = await getListEmployees({
                    full_name: searchDebount,
                    page_no: 0,
                    page_size: pageSize,
                    status,
                    user_group_id: role,
                })
            } else {
                res = await getListEmployees({
                    full_name: searchDebount,
                    page_no: pageIndex + 1,
                    page_size: pageSize,
                    status,
                    user_group_id: role,
                })
            }

            props.hideLoading()
            if (res.data.code == 200 && res.data.data) {
                const newList = res.data.data.data.map((e, i) => {
                    return { ...e, index: i + 1 + pageIndex * pageSize }
                })
                setData(newList)
                setTotalRecord(res.data.data.total_elements)
            } else if (res.data.code == 401) {
                localStorage.removeItem(KEY.API_TOKEN)
                setTimeout(() => {
                    history.push('/')
                }, 100)
            } else {
                toast.error(t(res.data.error), {
                    theme: 'colored',
                })
            }
        } catch (error) {}
    }

    useEffect(() => {
        getData(true)
    }, [searchDebount, status, role])
    useEffect(() => {
        getData(false)
    }, [pageIndex])

    const removeItem = async (id) => {
        props.showLoading()
        const res = await deleteEmployee({ id })
        props.hideLoading()
        if (res.data.code == 200) {
            getData(true)
            toast.success('Xoá bản ghi thành công!', {
                theme: 'colored',
            })
        } else if (res.data.code == 401) {
            localStorage.removeItem(KEY.API_TOKEN)
            setTimeout(() => {
                history.push('/')
            }, 100)
        } else {
            toast.error(t(res.data.error), {
                theme: 'colored',
            })
        }
    }

    const getUserGroup = async () => {
        const res = await dropdownUserGroup({})

        if (res.data.code == 200 && res.data.data) {
            setListRole(res.data.data)
        } else if (res.data.code == 401) {
            setTimeout(() => {
                history.push('/')
            }, 100)
        } else {
            toast.error(t(res.data.error), {
                theme: 'colored',
            })
        }
    }

    return (
        <ToolUserView
            data={data}
            removeItem={removeItem}
            setTxtSearch={setTxtSearch}
            setActiveSeleted={setActiveSeleted}
            pageIndex={pageIndex}
            changeActive={changeActive}
            setChangeActive={setChangeActive}
            setPageIndex={setPageIndex}
            activeSelected={activeSelected}
            handeChangeActive={handeChangeActive}
            totalRecords={totalRecords}
            permissions={permissions}
            status={status}
            setStatus={setStatus}
            role={role}
            setRole={setRole}
            listRole={listRole}
        />
    )
}

const mapStateToProps = (state) => {
    return {}
}
export default connect(mapStateToProps, { showLoading, hideLoading })(
    ToolNotificate
)
