import React, { useState } from 'react'
import {
    Paper,
    Table,
    TableBody,
    TableCell,
    TableHead,
    TableContainer,
    TablePagination,
    TableRow,
    IconButton,
    MenuItem,
    Tooltip,
    Icon,
} from '@material-ui/core'
import EditIcon from '@material-ui/icons/Edit'
import DeleteIcon from '@material-ui/icons/Delete'
import colors from 'app/assets/Color'
import useStyles from 'app/styles/Table'
import { Breadcrumb, SimpleCard } from 'app/components'
import DialogTransition from 'app/components/dialog/DialogTransition'
import { toPriceVnd } from 'app/config/Function'

const columns = [
    {
        id: 'index',
        label: 'STT',
        align: 'center',
        minWidth: 80,
    },
    {
        id: 'created_date',
        label: 'Thời gian',
        align: 'left',
        minWidth: 90,
    },

    {
        id: 'order_code',
        label: 'Mã giao dịch',
        align: 'left',
        minWidth: 170,
    },

    {
        id: 'store_name',
        label: 'Cây xăng',
        align: 'left',
        minWidth: 160,
    },
    {
        id: 'type_payment',
        label: 'Phương thức thanh toán',
        align: 'left',
        minWidth: 105,
    },

    {
        id: 'price',
        label: 'Số tiền',
        align: 'left',
        minWidth: 80,
        isMonney: true,
    },
    {
        id: 'commission',
        label: 'Hoa hồng',
        align: 'left',
        minWidth: 80,
        isMonney: true,
    },
]

function TableList(props) {
    const classes = useStyles()
    const {
        data,
        handeChangeActive,
        removeItem,
        changeActive,
        setChangeActive,
        setPageIndex,
        setPageSize,
        pageIndex,
        totalRecords,
        isDetail,
    } = props
    const [open, setOpen] = React.useState(false)
    const [selected, setSelected] = useState({
        name: '',
        id: '',
        title: '',
        content: '',
    })
    const handleChangePage = (event, newPage) => {
        setPageIndex(newPage)
    }
    const handleChangeRowsPerPage = (event) => {
        setPageSize(event.target.value)
    }
    const handleClose = () => {
        setOpen(false)
    }

    return (
        <Paper className={classes.root}>
            <TableContainer className={classes.container}>
                <Table stickyHeader aria-label="sticky table">
                    <TableHead>
                        <TableRow>
                            {columns.map((column) => (
                                <TableCell
                                    key={column.id}
                                    align={'center'}
                                    style={{
                                        width: column.minWidth,
                                        backgroundColor: colors.headerTable,
                                    }}
                                >
                                    {column.label}
                                </TableCell>
                            ))}
                            {!isDetail ? (
                                <TableCell
                                    style={{
                                        textAlign: 'center',
                                        backgroundColor: colors.headerTable,
                                        width: 60,
                                    }}
                                ></TableCell>
                            ) : null}
                        </TableRow>
                    </TableHead>
                    <TableBody className={classes.columnTable}>
                        {data.map((row) => {
                            return (
                                <TableRow
                                    hover
                                    role="checkbox"
                                    tabIndex={-1}
                                    key={row.id}
                                >
                                    {columns.map((column) => {
                                        const data = row[column.id]
                                        return (
                                            <TableCell
                                                key={column.id}
                                                align={column.align}
                                                style={{
                                                    textAlign:
                                                        column.id === 'index'
                                                            ? 'center'
                                                            : typeof data ==
                                                              'string'
                                                            ? 'left'
                                                            : 'right',
                                                }}
                                            >
                                                {column.isMonney
                                                    ? toPriceVnd(data)
                                                    : data}
                                            </TableCell>
                                        )
                                    })}
                                    {!isDetail ? (
                                        <TableCell>
                                            <Tooltip title="Xoá">
                                                <IconButton
                                                    onClick={() => {
                                                        setSelected({
                                                            ...row,
                                                            title: 'Xóa giao dịch trong phiếu đối soát',
                                                            content: `Bạn có muốn xóa giao dịch ${row.order_code} trong phiếu đối soát hay không?`,
                                                        })
                                                        setOpen(true)
                                                    }}
                                                    className={classes.button}
                                                    aria-label="Delete"
                                                >
                                                    <Icon color="error">
                                                        cancel
                                                    </Icon>
                                                </IconButton>
                                            </Tooltip>
                                        </TableCell>
                                    ) : null}
                                </TableRow>
                            )
                        })}
                    </TableBody>
                </Table>
            </TableContainer>
            <TablePagination
                component="div"
                page={pageIndex}
                count={totalRecords}
                rowsPerPage={10}
                rowsPerPageOptions={[]}
                onChangePage={handleChangePage}
                onChangeRowsPerPage={handleChangeRowsPerPage}
            />
            <DialogTransition
                data={selected}
                open={open}
                handleClose={handleClose}
                onAgree={() => {
                    removeItem(selected.id)
                    handleClose()
                }}
            />
        </Paper>
    )
}

export default TableList
