import React, { useState, useEffect } from 'react'
import ToolUserView from './view'
import {
    getListPageStatic,
    deletePageStatic,
    changeStatusPageStatic,
} from 'app/apis/Functions/pageStatic'
import { useHistory } from 'react-router-dom'
import KEY from '../../../assets/Key'
import { connect } from 'react-redux'
import { showLoading, hideLoading } from 'app/redux/actions/loadingAction'
import { toast } from 'react-toastify'
const ToolNotificate = (props) => {
    const [txtSearch, setTxtSearch] = useState('')
    const [activeSelected, setActiveSeleted] = useState(null)
    const [changeActive, setChangeActive] = useState(1)
    const [pageIndex, setPageIndex] = useState(0)
    const [pageSize] = useState(10)
    const [totalRecords, setTotalRecord] = useState(0)
    const history = useHistory()

    const [data, setData] = useState([])
    const [permissions, setPermissions] = useState([])

    useEffect(() => {
        getData()
    }, [txtSearch, pageIndex])

    const handeChangeActive = async (id, status_id) => {
        props.showLoading()
        const res = await changeStatusPageStatic({ id, status_id })
        props.hideLoading()
        if (res.data.code == 200) {
            getData()
            toast.success('Thay đổi trạng thái thành công!', {
                theme: 'colored',
            })
        } else {
            toast.success('Thay đổi trạng thái thất bại!', {
                theme: 'colored',
            })
        }
    }

    const getData = async () => {
        props.showLoading()
        const res = await getListPageStatic({
            name: txtSearch,
            page_no: pageIndex + 1,
            page_size: pageSize,
        })
        props.hideLoading()

        if (res.data.code == 200 && res.data.data) {
            console.log(res.data)
            const newList = res.data.data?.data.map((e, i) => {
                return { ...e, index: i + 1 + pageIndex * pageSize }
            })

            setData(newList)
            setTotalRecord(res.data.data.total_elements)
        } else if (res.data.code == 401) {
            localStorage.removeItem(KEY.API_TOKEN)
            setTimeout(() => {
                history.push('/')
            }, 100)
        } else {
            // enqueueSnackbar('Error!', { variant: 'error' })
        }
    }

    const removeItem = async (id) => {
        props.showLoading()
        const res = await deletePageStatic({ id })
        props.hideLoading()
        if (res.data.code == 200) {
            getData()
            toast.success('Xoá bản ghi thành công!', {
                theme: 'colored',
            })
        } else if (res.data.code == 401) {
            localStorage.removeItem(KEY.API_TOKEN)
            setTimeout(() => {
                history.push('/')
            }, 100)
        } else {
            toast.error('Xoá bản ghi thất bại!', {
                theme: 'colored',
            })
        }
    }

    return (
        <ToolUserView
            data={data}
            removeItem={removeItem}
            setTxtSearch={setTxtSearch}
            setActiveSeleted={setActiveSeleted}
            pageIndex={pageIndex}
            changeActive={changeActive}
            setChangeActive={setChangeActive}
            setPageIndex={setPageIndex}
            activeSelected={activeSelected}
            handeChangeActive={handeChangeActive}
            totalRecords={totalRecords}
            permissions={permissions}
        />
    )
}

const mapStateToProps = (state) => {
    return {}
}
export default connect(mapStateToProps, { showLoading, hideLoading })(
    ToolNotificate
)
