import React, { useState, useEffect } from 'react'
import ToolUserView from './View'
import {
    getListProduct,
    changeStatusProduct,
    deleteProduct,
} from 'app/apis/Functions/product'
import { useHistory } from 'react-router-dom'
import KEY from '../../../assets/Key'
import { connect } from 'react-redux'
import { showLoading, hideLoading } from 'app/redux/actions/loadingAction'
import { toast } from 'react-toastify'
import useDebounce from 'app/hooks/useDebounce'
import { useTranslation } from 'react-i18next'
import { dropdownProductType } from 'app/apis/Functions/dropdown'
const ToolNotificate = (props) => {
    const [txtSearch, setTxtSearch] = useState('')
    const [activeSelected, setActiveSeleted] = useState(null)
    const [changeActive, setChangeActive] = useState(1)
    const searchDebount = useDebounce(txtSearch, 1000)
    const [status, setStatus] = useState()
    const [pageIndex, setPageIndex] = useState(0)
    const [pageSize] = useState(10)
    const [totalRecords, setTotalRecord] = useState(0)
    const [type, setType] = useState()
    const [listType, setListType] = useState([])

    const history = useHistory()
    const { t } = useTranslation()
    const [data, setData] = useState([])
    const [permissions, setPermissions] = useState([])

    useEffect(() => {
        getListType()
    }, [])

    const handeChangeActive = async (id, status_id) => {
        props.showLoading()
        const res = await changeStatusProduct({ idGuid: id, status_id })
        props.hideLoading()
        if (res.data.code == 200) {
            getData()
            toast.success('Thay đổi trạng thái thành công!', {
                theme: 'colored',
            })
        } else {
            toast.error(t(res.data.error), {
                theme: 'colored',
            })
        }
    }

    const getData = async (init) => {
        props.showLoading()
        let res
        if (init) {
            setPageIndex(0)
            res = await getListProduct({
                code: searchDebount,
                page_no: 0,
                page_size: pageSize,
                status,
                type_id: type,
            })
        } else {
            res = await getListProduct({
                code: searchDebount,
                page_no: pageIndex + 1,
                page_size: pageSize,
                status,
                type_id: type,
            })
        }
        props.hideLoading()

        if (res.data.code == 200 && res.data.data) {
            console.log(res.data)
            const newList = res.data.data.data.map((e, i) => {
                return { ...e, index: i + 1 + pageIndex * pageSize }
            })

            setData(newList)
            setTotalRecord(res.data.data.total_elements)
        } else if (res.data.code == 401) {
            localStorage.removeItem(KEY.API_TOKEN)
            setTimeout(() => {
                history.push('/')
            }, 100)
        } else {
            toast.error(t(res.data.error), {
                theme: 'colored',
            })
        }
    }

    useEffect(() => {
        getData(false)
    }, [pageIndex])

    useEffect(() => {
        getData(true)
    }, [searchDebount, status, type])

    const removeItem = async (id) => {
        props.showLoading()
        const res = await deleteProduct({ idGuid: id })
        props.hideLoading()
        if (res.data.code == 200) {
            getData()
            toast.success('Xoá bản ghi thành công!', {
                theme: 'colored',
            })
        } else if (res.data.code == 401) {
            localStorage.removeItem(KEY.API_TOKEN)
            setTimeout(() => {
                history.push('/')
            }, 100)
        } else {
            toast.error(t(res.data.error), {
                theme: 'colored',
            })
        }
    }

    const getListType = async () => {
        const res = await dropdownProductType({})

        if (res.data.code == 200 && res.data.data) {
            const newList = res.data.data.map((e) => {
                return { name: e.type_name, value: e.id, ...e }
            })
            setListType(newList)
        } else {
            toast.error(t(res.data.error), {
                theme: 'colored',
            })
        }
    }

    return (
        <ToolUserView
            data={data}
            removeItem={removeItem}
            setTxtSearch={setTxtSearch}
            setActiveSeleted={setActiveSeleted}
            pageIndex={pageIndex}
            changeActive={changeActive}
            setChangeActive={setChangeActive}
            setPageIndex={setPageIndex}
            activeSelected={activeSelected}
            handeChangeActive={handeChangeActive}
            totalRecords={totalRecords}
            permissions={permissions}
            status={status}
            setStatus={setStatus}
            listType={listType}
            type={type}
            setType={setType}
        />
    )
}

const mapStateToProps = (state) => {
    return {}
}
export default connect(mapStateToProps, { showLoading, hideLoading })(
    ToolNotificate
)
